pub enum LocatorDirection {
Within,
After,
Before,
}Variants
Within
Search inside each selected parent match.
After
Search after each parent, stopping at the next selected parent.
Before
Search before each parent, starting after the previous selected parent.