pub struct Locator { /* private fields */ }Expand description
A lazy query resolved against the current terminal grid before every read, wait, or action.
Implementations
Sourceimpl Locator
impl Locator
pub fn query(&self) -> &LocatorQuery
Sourcepub fn and(&self, other: &Self) -> Result<Self, TuiTestError>
pub fn and(&self, other: &Self) -> Result<Self, TuiTestError>
Intersect selected cells and form contiguous per-row runs.
Sourcepub fn or(&self, other: &Self) -> Result<Self, TuiTestError>
pub fn or(&self, other: &Self) -> Result<Self, TuiTestError>
Union selected cells and form contiguous per-row runs.
pub fn filter( &self, options: LocatorFilterOptions, ) -> Result<Self, TuiTestError>
Sourcepub fn get_by_link(&self, selector: impl Into<LinkSelector>) -> Self
pub fn get_by_link(&self, selector: impl Into<LinkSelector>) -> Self
Require every cell of each current match to have this link.
pub fn get_by_link_relative( &self, selector: impl Into<LinkSelector>, direction: LocatorDirection, ) -> Self
pub fn get_by_text(&self, selector: impl Into<TextSelector>) -> Self
pub fn get_by_text_relative( &self, selector: impl Into<TextSelector>, direction: LocatorDirection, ) -> Self
pub fn get_by_style(&self, selector: impl Into<StyleSelector>) -> Self
pub fn get_by_style_relative( &self, selector: impl Into<StyleSelector>, direction: LocatorDirection, ) -> Self
pub fn any(&self) -> Self
pub fn unique(&self) -> Self
pub fn first(&self) -> Self
pub fn last(&self) -> Self
pub fn nth(&self, index: usize) -> Self
pub fn all(&self) -> Result<Vec<Self>, TuiTestError>
pub fn count(&self) -> Result<usize, TuiTestError>
pub fn locations(&self) -> Result<Vec<TextMatch>, TuiTestError>
pub fn location(&self) -> Result<TextMatch, TuiTestError>
pub fn wait(&self) -> Result<(), TuiTestError>
pub fn wait_with_timeout( &self, timeout_ms: Option<u64>, ) -> Result<(), TuiTestError>
pub fn click(&self) -> Result<(), TuiTestError>
pub fn click_with( &self, options: LocatorClickOptions, ) -> Result<(), TuiTestError>
pub fn highlight(&self) -> Result<(), TuiTestError>
pub fn highlight_with_timeout( &self, timeout_ms: Option<u64>, ) -> Result<(), TuiTestError>
pub fn expect(&self) -> Result<(), TuiTestError>
pub fn expect_with( &self, options: LocatorExpectOptions, ) -> Result<(), TuiTestError>